@@ -22,7 +22,7 @@ class Photo(models.Model):
     height = models.PositiveIntegerField(_('Height'), editable=False)
     width = models.PositiveIntegerField(_('Width'), editable=False)
     display = models.BooleanField(_('Display'), default=True, help_text=_('Enable to display this photo.'))
-    name = models.CharField(_('Name'), max_length=250, help_text=_('If no name is given, it is created from filename.'))
+    name = models.CharField(_('Name'), max_length=250, help_text=_('If no name is given, it is created from filename.'), blank=True)
     description = models.TextField(_('Description'), blank=True, null=True)
     user = models.ForeignKey(User, editable=False, blank=True, null=True)
     tags = TaggableManager()
